/* rygel-tracker-query-filter.c generated by valac 0.15.2.4-51044, the Vala compiler
 * generated from rygel-tracker-query-filter.vala, do not modify */

/*
 * Copyright (C) 2010 MediaNet Inh.
 *
 * Author: Sunil Mohan Adapa <sunil@medhas.org>
 *
 * This file is part of Rygel.
 *
 * Rygel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Rygel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>


#define RYGEL_TRACKER_TYPE_QUERY_FILTER (rygel_tracker_query_filter_get_type ())
#define RYGEL_TRACKER_QUERY_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), RYGEL_TRACKER_TYPE_QUERY_FILTER, RygelTrackerQueryFilter))
#define RYGEL_TRACKER_IS_QUERY_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), RYGEL_TRACKER_TYPE_QUERY_FILTER))
#define RYGEL_TRACKER_QUERY_FILTER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), RYGEL_TRACKER_TYPE_QUERY_FILTER, RygelTrackerQueryFilterIface))

typedef struct _RygelTrackerQueryFilter RygelTrackerQueryFilter;
typedef struct _RygelTrackerQueryFilterIface RygelTrackerQueryFilterIface;

struct _RygelTrackerQueryFilterIface {
	GTypeInterface parent_iface;
	gchar* (*to_string) (RygelTrackerQueryFilter* self);
};



GType rygel_tracker_query_filter_get_type (void) G_GNUC_CONST;
gchar* rygel_tracker_query_filter_to_string (RygelTrackerQueryFilter* self);


gchar* rygel_tracker_query_filter_to_string (RygelTrackerQueryFilter* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return RYGEL_TRACKER_QUERY_FILTER_GET_INTERFACE (self)->to_string (self);
}


static void rygel_tracker_query_filter_base_init (RygelTrackerQueryFilterIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


/**
 * An expression in SPARQL query filter
 */
GType rygel_tracker_query_filter_get_type (void) {
	static volatile gsize rygel_tracker_query_filter_type_id__volatile = 0;
	if (g_once_init_enter (&rygel_tracker_query_filter_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (RygelTrackerQueryFilterIface), (GBaseInitFunc) rygel_tracker_query_filter_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType rygel_tracker_query_filter_type_id;
		rygel_tracker_query_filter_type_id = g_type_register_static (G_TYPE_INTERFACE, "RygelTrackerQueryFilter", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (rygel_tracker_query_filter_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&rygel_tracker_query_filter_type_id__volatile, rygel_tracker_query_filter_type_id);
	}
	return rygel_tracker_query_filter_type_id__volatile;
}



